@@ -12,9 +12,11 @@ def stitch_videos(
 ):
     import os
     import ffmpeg
+    from loguru import logger
 
     def concat_videos(input_videos_dir_path, output_path):
         videos = os.listdir(input_videos_dir_path)
+        logger.info(f"videos: {videos}")
         ffmpeg_inputs = [
             ffmpeg.input(os.path.join(input_videos_dir_path, video)) for video in videos
         ]
